Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(121)

Unified Diff: chrome/browser/ui/views/page_info/page_info_popup_view.h

Issue 2737413004: Add a Certificate Viewer link to the Page Info dropdown (Closed)
Patch Set: Add Cocoa, Fix MaxViews, Add Flag Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/page_info/page_info_popup_view.h
diff --git a/chrome/browser/ui/views/page_info/page_info_popup_view.h b/chrome/browser/ui/views/page_info/page_info_popup_view.h
index c8843627be5827c6c3d7f830ad43e9ad035768e4..c9ed66f25af0105ac7b310b8354cf2d0e2ac9ab3 100644
--- a/chrome/browser/ui/views/page_info/page_info_popup_view.h
+++ b/chrome/browser/ui/views/page_info/page_info_popup_view.h
@@ -6,6 +6,7 @@
#define CHROME_BROWSER_UI_VIEWS_PAGE_INFO_PAGE_INFO_POPUP_VIEW_H_
#include <memory>
+#include <vector>
#include "base/compiler_specific.h"
#include "base/macros.h"
@@ -142,9 +143,6 @@ class PageInfoPopupView : public content::WebContentsObserver,
// be alive to finish handling the mouse or keyboard click.
void HandleLinkClickedAsync(views::Link* source);
- // Whether DevTools is disabled for the relevant profile.
- bool is_devtools_disabled_;
-
// The presenter that controls the Page Info UI.
std::unique_ptr<PageInfo> presenter_;
@@ -159,8 +157,13 @@ class PageInfoPopupView : public content::WebContentsObserver,
// The separator between the header and the site settings view.
views::Separator* separator_;
// The view that contains the cookie and permissions sections.
views::View* site_settings_view_;
+ // The view that contains the contents of the "Certificate" part of the site
+ // settings view.
+ views::View* certificate_view_;
+ // The link that opens the Certificate viewer.
+ views::Link* certificate_viewer_link_;
// The view that contains the contents of the "Cookies" part of the site
// settings view.
views::View* cookies_view_;
@@ -159,8 +157,13 @@ class PageInfoPopupView : public content::WebContentsObserver,
// The separator between the header and the site settings view.
views::Separator* separator_;
- // The view that contains the cookie and permissions sections.
+ // The view that contains the certificate, cookie, and permissions sections.
views::View* site_settings_view_;

Powered by Google App Engine
This is Rietveld 408576698